@@ -36,6 +36,10 @@ lc, encoding = locale.getdefaultlocale()
 if lc:
  languages = [lc]
 
+#for help file
+a=lc.split("_")
+data.language=a[0]
+#print data.language
 
 # Concat all languages (env + default locale),
 #  and here we have the languages and location of the translations
@@ -63,3 +67,5 @@ gettext.textdomain (APP_NAME)
 language = gettext.translation (APP_NAME, mo_location, languages = languages, fallback = True)
 
 
+
+
