@@ -556,7 +556,7 @@ class frmStartWindow(QMainWindow):
         LoadFileList()
         data.arrRecordFilesIndex=len(data.arrRecordFiles)-1 #no file selected, show latest
 
-        if os.path.exists(data.RecordFolder+data.LastRecord):
+        if(os.path.exists(data.RecordFolder+data.LastRecord)):
             data.RecordFilename=data.LastRecord
         else:
             l=len(data.arrRecordFiles)
@@ -1313,8 +1313,15 @@ class frmHelpWindow(QMainWindow):
 
 
     def load_data(self):
-#        TODO: support multilingual info file
-        file = open(data.app_path+"Info.htm", 'r')
+        filename=data.app_path+"help_"+data.language+".htm"
+        if(os.path.exists(filename)):
+            print "Open help file:", filename
+        else:
+            print "Help file", filename, "does not exist"
+            filename=data.app_path+"help_en.htm"
+            print "Open default help file:", filename
+
+        file = open(filename, 'r')
         txt=""
         for line in file: txt=txt+line+"\n"
         file.close()
@@ -1506,7 +1513,7 @@ class frmDateWindow(QMainWindow):
 
         self.ui.cal.showToday()
 
-        self.setWindowTitle("SleepAnalyser ("+_("Select date)")+")")
+        self.setWindowTitle("SleepAnalyser ("+_("Select date")+")")
 
 
     ###########################################################################
